#
# spec file for package mingw32-cross-wine
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _with_dns 0

%define _rpm_macros_dir %{_rpmconfigdir}/macros.d

Name:           mingw32-cross-wine
Version:        1.3.2
Release:        2.5
Summary:        Wine cross runtime
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            http://www.winehq.org/
Source1:        macros
Source2:        wine.sh
%if %{?_with_dns}
# nslookup
Requires:       bind-utils
# dns server
Requires:       dnsmasq
BuildRequires:  NetworkManager
# netupdate for regenerating /etc/resolv.conf
Requires:       sysconfig
%endif
# i686-w64-mingw32-objdump
BuildRequires:  mingw32-cross-binutils
BuildRequires:  mingw32-filesystem
Requires:       mingw32-filesystem
Requires:       wget
Requires:       wine-binfmt-standalone
Requires:       winetricks
# Xvfb for x display
Requires:       xorg-x11-server
Requires:       xvfb-run
%_mingw32_package_header
BuildArch:      noarch
#!BuildIgnore: post-build-checks

%description
This package contains a ready to use wine prefix for
running cross compiled applications while building
packages, for example cross compiled test

%prep
%setup -c -T

%build

%install
mkdir -p %{buildroot}%{_rpm_macros_dir}
cp %{_sourcedir}/macros %{buildroot}%{_rpm_macros_dir}/macros.mingw32-cross-wine
cp %{_sourcedir}/wine.sh %{buildroot}%{_rpmconfigdir}/mingw32-cross-wine-wine.sh
mkdir -p %{buildroot}%{_bindir}
ln -s ../lib/mingw32-scripts %{buildroot}%{_bindir}/mingw32-cross-wine-init
ln -s ../lib/mingw32-scripts %{buildroot}%{_bindir}/mingw32-cross-wine-run
ln -s ../lib/mingw32-scripts %{buildroot}%{_bindir}/mingw32-cross-wine-start-session

%if %{?_with_dns}
%post
# setup dns config
set -x
# add dnsmasq as local dns server
sed -i '/^NETCONFIG_DNS_FORWARDER=/ s,"resolver","dnsmasq",g' /etc/sysconfig/network/config
sed -i '/^NETCONFIG_DNS_STATIC_SERVERS=/ s,"","127.0.0.1",g' /etc/sysconfig/network/config
sed -i '/^DEBUG=/ s,"no","yes",g' /etc/sysconfig/network/config
sed -i '/^NETCONFIG_VERBOSE=/ s,"no","yes",g' /etc/sysconfig/network/config

cat /etc/sysconfig/network/config

# update /etc/resolv.conf
netconfig update -f
cat /etc/resolv.conf

cat /var/run/dnsmasq-forwarders.conf

#  setup dns server
cat << EOF >> /etc/dnsmasq.conf
listen-address=127.0.0.1
port=53
domain-needed
bogus-priv
resolv-file=/var/run/dnsmasq-forwarders.conf
EOF

# start local dns server
/usr/sbin/dnsmasq -u root &

sleep 2

netstat -alnp

# check dns
dig 127.0.0.1
%endif

%if %{?_with_dns}
%preun
killall -9 dnsmasq
%endif

%files
%defattr(-,root,root)
%dir %{_rpmconfigdir}
%dir %{_rpm_macros_dir}
%{_rpm_macros_dir}/macros.mingw32-cross-wine
%{_rpmconfigdir}/mingw32-cross-wine-wine.sh
%{_bindir}/mingw32-*

%changelog
* Sun Apr 16 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Drop tag BuildRoot: (boo#1207289)
- Cleanup spec file
* Thu Jul 28 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Do not create wine prefix when running on aarch64 and ppc64le cpu host
  as wine support on this architectures is currently not working
* Fri Apr  1 2022 Ralf Habacker <ralf.habacker@freenet.de>
- updated to 1.3.2
  * fix bug using different wine prefixes
  * move all wine related processing into wine.sh to have a clean
    separation
* Mon Mar 28 2022 Ralf Habacker <ralf.habacker@freenet.de>
- updated to 1.3.1
  * Use 'winetricks set_userpath' to set wine paths
  * Fix winetricks warnings by adding wget and env vars
* Sun Jan  9 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Add winetricks and use to disable crash dialog and winedbg
* Sat Oct 17 2020 Ralf Habacker <ralf.habacker@freenet.de>
- 1.3.0
  * Add shell wrapper mingw32-cross-wine-init, mingw32-cross-wine-run
    and mingw32-cross-wine-start-session
  * Use a custom wine prefix to preserve existing ones
  * Remove generated temporary file
* Thu Aug 27 2020 Ralf Habacker <ralf.habacker@freenet.de>
- 1.2.0:
  * Add rpm macro _mingw32_cross_wine_start_session
  * Remove obsolete file mingw32-cross-wine.rpmlintrc
    as mingw32-filesystem already provides the same filter
* Sun Jun 21 2020 Ralf Habacker <ralf.habacker@freenet.de>
- 1.1.0:
  * Add wine.sh and user-path.reg.in
* Mon Feb 16 2015 ralf.habacker@freenet.de
- place cross wine setup into rpm macro
